import typing_extensions

from circle.paths import PathValues
from circle.apis.paths.ping import Ping
from circle.apis.paths.v1_configuration import V1Configuration
from circle.apis.paths.v1_encryption_public import V1EncryptionPublic
from circle.apis.paths.v1_notifications_subscriptions import V1NotificationsSubscriptions
from circle.apis.paths.v1_notifications_subscriptions_id import V1NotificationsSubscriptionsId
from circle.apis.paths.v1_channels import V1Channels
from circle.apis.paths.v1_stablecoins import V1Stablecoins
from circle.apis.paths.v1_business_account_balances import V1BusinessAccountBalances
from circle.apis.paths.v1_balances import V1Balances
from circle.apis.paths.v1_cards import V1Cards
from circle.apis.paths.v1_cards_id import V1CardsId
from circle.apis.paths.v1_payment_tokens import V1PaymentTokens
from circle.apis.paths.v1_business_account_banks_wires import V1BusinessAccountBanksWires
from circle.apis.paths.v1_business_account_banks_wires_id import V1BusinessAccountBanksWiresId
from circle.apis.paths.v1_business_account_banks_wires_id_instructions import V1BusinessAccountBanksWiresIdInstructions
from circle.apis.paths.v1_business_account_banks_cbit import V1BusinessAccountBanksCbit
from circle.apis.paths.v1_business_account_banks_cbit_id import V1BusinessAccountBanksCbitId
from circle.apis.paths.v1_business_account_banks_cbit_id_instructions import V1BusinessAccountBanksCbitIdInstructions
from circle.apis.paths.v1_business_account_wallets_addresses_deposit import V1BusinessAccountWalletsAddressesDeposit
from circle.apis.paths.v1_business_account_wallets_addresses_recipient import V1BusinessAccountWalletsAddressesRecipient
from circle.apis.paths.v1_business_account_deposits import V1BusinessAccountDeposits
from circle.apis.paths.v1_payment_intents import V1PaymentIntents
from circle.apis.paths.v1_payment_intents_id import V1PaymentIntentsId
from circle.apis.paths.v1_payment_intents_id_expire import V1PaymentIntentsIdExpire
from circle.apis.paths.v1_payment_intents_id_refund import V1PaymentIntentsIdRefund
from circle.apis.paths.v1_address_book_recipients import V1AddressBookRecipients
from circle.apis.paths.v1_address_book_recipients_id import V1AddressBookRecipientsId
from circle.apis.paths.v1_payments import V1Payments
from circle.apis.paths.v1_payments_crypto import V1PaymentsCrypto
from circle.apis.paths.v1_payments_id import V1PaymentsId
from circle.apis.paths.v1_payments_id_capture import V1PaymentsIdCapture
from circle.apis.paths.v1_payments_id_cancel import V1PaymentsIdCancel
from circle.apis.paths.v1_payments_id_refund import V1PaymentsIdRefund
from circle.apis.paths.v1_payments_presign import V1PaymentsPresign
from circle.apis.paths.v1_business_account_payouts import V1BusinessAccountPayouts
from circle.apis.paths.v1_business_account_payouts_id import V1BusinessAccountPayoutsId
from circle.apis.paths.v1_payouts import V1Payouts
from circle.apis.paths.v1_payouts_id import V1PayoutsId
from circle.apis.paths.v1_exchange_rates_trading_pair import V1ExchangeRatesTradingPair
from circle.apis.paths.v1_settlements import V1Settlements
from circle.apis.paths.v1_settlements_id import V1SettlementsId
from circle.apis.paths.v1_chargebacks import V1Chargebacks
from circle.apis.paths.v1_chargebacks_id import V1ChargebacksId
from circle.apis.paths.v1_wallets import V1Wallets
from circle.apis.paths.v1_wallets_wallet_id import V1WalletsWalletId
from circle.apis.paths.v1_wallets_wallet_id_addresses import V1WalletsWalletIdAddresses
from circle.apis.paths.v1_business_account_transfers import V1BusinessAccountTransfers
from circle.apis.paths.v1_business_account_transfers_id import V1BusinessAccountTransfersId
from circle.apis.paths.v1_transfers import V1Transfers
from circle.apis.paths.v1_transfers_id import V1TransfersId
from circle.apis.paths.v1_mocks_cards_chargebacks import V1MocksCardsChargebacks
from circle.apis.paths.v1_mocks_payments_wire import V1MocksPaymentsWire
from circle.apis.paths.v1_checkout_sessions import V1CheckoutSessions
from circle.apis.paths.v1_checkout_sessions_id import V1CheckoutSessionsId
from circle.apis.paths.v1_checkout_sessions_id_extend import V1CheckoutSessionsIdExtend

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.PING: Ping,
        PathValues.V1_CONFIGURATION: V1Configuration,
        PathValues.V1_ENCRYPTION_PUBLIC: V1EncryptionPublic,
        PathValues.V1_NOTIFICATIONS_SUBSCRIPTIONS: V1NotificationsSubscriptions,
        PathValues.V1_NOTIFICATIONS_SUBSCRIPTIONS_ID: V1NotificationsSubscriptionsId,
        PathValues.V1_CHANNELS: V1Channels,
        PathValues.V1_STABLECOINS: V1Stablecoins,
        PathValues.V1_BUSINESS_ACCOUNT_BALANCES: V1BusinessAccountBalances,
        PathValues.V1_BALANCES: V1Balances,
        PathValues.V1_CARDS: V1Cards,
        PathValues.V1_CARDS_ID: V1CardsId,
        PathValues.V1_PAYMENT_TOKENS: V1PaymentTokens,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES: V1BusinessAccountBanksWires,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID: V1BusinessAccountBanksWiresId,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID_INSTRUCTIONS: V1BusinessAccountBanksWiresIdInstructions,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT: V1BusinessAccountBanksCbit,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID: V1BusinessAccountBanksCbitId,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID_INSTRUCTIONS: V1BusinessAccountBanksCbitIdInstructions,
        PathValues.V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_DEPOSIT: V1BusinessAccountWalletsAddressesDeposit,
        PathValues.V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_RECIPIENT: V1BusinessAccountWalletsAddressesRecipient,
        PathValues.V1_BUSINESS_ACCOUNT_DEPOSITS: V1BusinessAccountDeposits,
        PathValues.V1_PAYMENT_INTENTS: V1PaymentIntents,
        PathValues.V1_PAYMENT_INTENTS_ID: V1PaymentIntentsId,
        PathValues.V1_PAYMENT_INTENTS_ID_EXPIRE: V1PaymentIntentsIdExpire,
        PathValues.V1_PAYMENT_INTENTS_ID_REFUND: V1PaymentIntentsIdRefund,
        PathValues.V1_ADDRESS_BOOK_RECIPIENTS: V1AddressBookRecipients,
        PathValues.V1_ADDRESS_BOOK_RECIPIENTS_ID: V1AddressBookRecipientsId,
        PathValues.V1_PAYMENTS: V1Payments,
        PathValues.V1_PAYMENTS_CRYPTO: V1PaymentsCrypto,
        PathValues.V1_PAYMENTS_ID: V1PaymentsId,
        PathValues.V1_PAYMENTS_ID_CAPTURE: V1PaymentsIdCapture,
        PathValues.V1_PAYMENTS_ID_CANCEL: V1PaymentsIdCancel,
        PathValues.V1_PAYMENTS_ID_REFUND: V1PaymentsIdRefund,
        PathValues.V1_PAYMENTS_PRESIGN: V1PaymentsPresign,
        PathValues.V1_BUSINESS_ACCOUNT_PAYOUTS: V1BusinessAccountPayouts,
        PathValues.V1_BUSINESS_ACCOUNT_PAYOUTS_ID: V1BusinessAccountPayoutsId,
        PathValues.V1_PAYOUTS: V1Payouts,
        PathValues.V1_PAYOUTS_ID: V1PayoutsId,
        PathValues.V1_EXCHANGE_RATES_TRADINGPAIR: V1ExchangeRatesTradingPair,
        PathValues.V1_SETTLEMENTS: V1Settlements,
        PathValues.V1_SETTLEMENTS_ID: V1SettlementsId,
        PathValues.V1_CHARGEBACKS: V1Chargebacks,
        PathValues.V1_CHARGEBACKS_ID: V1ChargebacksId,
        PathValues.V1_WALLETS: V1Wallets,
        PathValues.V1_WALLETS_WALLET_ID: V1WalletsWalletId,
        PathValues.V1_WALLETS_WALLET_ID_ADDRESSES: V1WalletsWalletIdAddresses,
        PathValues.V1_BUSINESS_ACCOUNT_TRANSFERS: V1BusinessAccountTransfers,
        PathValues.V1_BUSINESS_ACCOUNT_TRANSFERS_ID: V1BusinessAccountTransfersId,
        PathValues.V1_TRANSFERS: V1Transfers,
        PathValues.V1_TRANSFERS_ID: V1TransfersId,
        PathValues.V1_MOCKS_CARDS_CHARGEBACKS: V1MocksCardsChargebacks,
        PathValues.V1_MOCKS_PAYMENTS_WIRE: V1MocksPaymentsWire,
        PathValues.V1_CHECKOUT_SESSIONS: V1CheckoutSessions,
        PathValues.V1_CHECKOUT_SESSIONS_ID: V1CheckoutSessionsId,
        PathValues.V1_CHECKOUT_SESSIONS_ID_EXTEND: V1CheckoutSessionsIdExtend,
    }
)

path_to_api = PathToApi(
    {
        PathValues.PING: Ping,
        PathValues.V1_CONFIGURATION: V1Configuration,
        PathValues.V1_ENCRYPTION_PUBLIC: V1EncryptionPublic,
        PathValues.V1_NOTIFICATIONS_SUBSCRIPTIONS: V1NotificationsSubscriptions,
        PathValues.V1_NOTIFICATIONS_SUBSCRIPTIONS_ID: V1NotificationsSubscriptionsId,
        PathValues.V1_CHANNELS: V1Channels,
        PathValues.V1_STABLECOINS: V1Stablecoins,
        PathValues.V1_BUSINESS_ACCOUNT_BALANCES: V1BusinessAccountBalances,
        PathValues.V1_BALANCES: V1Balances,
        PathValues.V1_CARDS: V1Cards,
        PathValues.V1_CARDS_ID: V1CardsId,
        PathValues.V1_PAYMENT_TOKENS: V1PaymentTokens,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES: V1BusinessAccountBanksWires,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID: V1BusinessAccountBanksWiresId,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID_INSTRUCTIONS: V1BusinessAccountBanksWiresIdInstructions,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT: V1BusinessAccountBanksCbit,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID: V1BusinessAccountBanksCbitId,
        PathValues.V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID_INSTRUCTIONS: V1BusinessAccountBanksCbitIdInstructions,
        PathValues.V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_DEPOSIT: V1BusinessAccountWalletsAddressesDeposit,
        PathValues.V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_RECIPIENT: V1BusinessAccountWalletsAddressesRecipient,
        PathValues.V1_BUSINESS_ACCOUNT_DEPOSITS: V1BusinessAccountDeposits,
        PathValues.V1_PAYMENT_INTENTS: V1PaymentIntents,
        PathValues.V1_PAYMENT_INTENTS_ID: V1PaymentIntentsId,
        PathValues.V1_PAYMENT_INTENTS_ID_EXPIRE: V1PaymentIntentsIdExpire,
        PathValues.V1_PAYMENT_INTENTS_ID_REFUND: V1PaymentIntentsIdRefund,
        PathValues.V1_ADDRESS_BOOK_RECIPIENTS: V1AddressBookRecipients,
        PathValues.V1_ADDRESS_BOOK_RECIPIENTS_ID: V1AddressBookRecipientsId,
        PathValues.V1_PAYMENTS: V1Payments,
        PathValues.V1_PAYMENTS_CRYPTO: V1PaymentsCrypto,
        PathValues.V1_PAYMENTS_ID: V1PaymentsId,
        PathValues.V1_PAYMENTS_ID_CAPTURE: V1PaymentsIdCapture,
        PathValues.V1_PAYMENTS_ID_CANCEL: V1PaymentsIdCancel,
        PathValues.V1_PAYMENTS_ID_REFUND: V1PaymentsIdRefund,
        PathValues.V1_PAYMENTS_PRESIGN: V1PaymentsPresign,
        PathValues.V1_BUSINESS_ACCOUNT_PAYOUTS: V1BusinessAccountPayouts,
        PathValues.V1_BUSINESS_ACCOUNT_PAYOUTS_ID: V1BusinessAccountPayoutsId,
        PathValues.V1_PAYOUTS: V1Payouts,
        PathValues.V1_PAYOUTS_ID: V1PayoutsId,
        PathValues.V1_EXCHANGE_RATES_TRADINGPAIR: V1ExchangeRatesTradingPair,
        PathValues.V1_SETTLEMENTS: V1Settlements,
        PathValues.V1_SETTLEMENTS_ID: V1SettlementsId,
        PathValues.V1_CHARGEBACKS: V1Chargebacks,
        PathValues.V1_CHARGEBACKS_ID: V1ChargebacksId,
        PathValues.V1_WALLETS: V1Wallets,
        PathValues.V1_WALLETS_WALLET_ID: V1WalletsWalletId,
        PathValues.V1_WALLETS_WALLET_ID_ADDRESSES: V1WalletsWalletIdAddresses,
        PathValues.V1_BUSINESS_ACCOUNT_TRANSFERS: V1BusinessAccountTransfers,
        PathValues.V1_BUSINESS_ACCOUNT_TRANSFERS_ID: V1BusinessAccountTransfersId,
        PathValues.V1_TRANSFERS: V1Transfers,
        PathValues.V1_TRANSFERS_ID: V1TransfersId,
        PathValues.V1_MOCKS_CARDS_CHARGEBACKS: V1MocksCardsChargebacks,
        PathValues.V1_MOCKS_PAYMENTS_WIRE: V1MocksPaymentsWire,
        PathValues.V1_CHECKOUT_SESSIONS: V1CheckoutSessions,
        PathValues.V1_CHECKOUT_SESSIONS_ID: V1CheckoutSessionsId,
        PathValues.V1_CHECKOUT_SESSIONS_ID_EXTEND: V1CheckoutSessionsIdExtend,
    }
)



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ReversalReason(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated reason for a returned payment. Providing this reason in the request is recommended (to improve risk evaluation) but not required.
    """


    class MetaOapg:
        enum_value_to_name = {
            "duplicate": "DUPLICATE",
            "fraudulent": "FRAUDULENT",
            "requested_by_customer": "REQUESTED_BY_CUSTOMER",
            "bank_transaction_error": "BANK_TRANSACTION_ERROR",
            "invalid_account_number": "INVALID_ACCOUNT_NUMBER",
            "insufficient_funds": "INSUFFICIENT_FUNDS",
            "payment_stopped_by_issuer": "PAYMENT_STOPPED_BY_ISSUER",
            "payment_returned": "PAYMENT_RETURNED",
            "bank_account_ineligible": "BANK_ACCOUNT_INELIGIBLE",
            "invalid_ach_rtn": "INVALID_ACH_RTN",
            "unauthorized_transaction": "UNAUTHORIZED_TRANSACTION",
            "payment_failed": "PAYMENT_FAILED",
        }
    
    @schemas.classproperty
    def DUPLICATE(cls):
        return cls("duplicate")
    
    @schemas.classproperty
    def FRAUDULENT(cls):
        return cls("fraudulent")
    
    @schemas.classproperty
    def REQUESTED_BY_CUSTOMER(cls):
        return cls("requested_by_customer")
    
    @schemas.classproperty
    def BANK_TRANSACTION_ERROR(cls):
        return cls("bank_transaction_error")
    
    @schemas.classproperty
    def INVALID_ACCOUNT_NUMBER(cls):
        return cls("invalid_account_number")
    
    @schemas.classproperty
    def INSUFFICIENT_FUNDS(cls):
        return cls("insufficient_funds")
    
    @schemas.classproperty
    def PAYMENT_STOPPED_BY_ISSUER(cls):
        return cls("payment_stopped_by_issuer")
    
    @schemas.classproperty
    def PAYMENT_RETURNED(cls):
        return cls("payment_returned")
    
    @schemas.classproperty
    def BANK_ACCOUNT_INELIGIBLE(cls):
        return cls("bank_account_ineligible")
    
    @schemas.classproperty
    def INVALID_ACH_RTN(cls):
        return cls("invalid_ach_rtn")
    
    @schemas.classproperty
    def UNAUTHORIZED_TRANSACTION(cls):
        return cls("unauthorized_transaction")
    
    @schemas.classproperty
    def PAYMENT_FAILED(cls):
        return cls("payment_failed")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_deposits.get import ListBusinessDeposits


class DepositsApi(
    ListBusinessDeposits,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class TokenizedCardDetails(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expMonth",
            "last4",
            "expYear",
            "bin",
        }
        
        class properties:
            expMonth = schemas.IntSchema
            expYear = schemas.IntSchema
            last4 = schemas.StrSchema
            bin = schemas.StrSchema
            
            
            class network(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def VISA(cls):
                    return cls("VISA")
                
                @schemas.classproperty
                def MASTERCARD(cls):
                    return cls("MASTERCARD")
                
                @schemas.classproperty
                def AMEX(cls):
                    return cls("AMEX")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("UNKNOWN")
            
            
            class fundingType(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("credit")
                
                @schemas.classproperty
                def DEBIT(cls):
                    return cls("debit")
                
                @schemas.classproperty
                def PREPAID(cls):
                    return cls("prepaid")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("unknown")
            issuerCountry = schemas.StrSchema
            __annotations__ = {
                "expMonth": expMonth,
                "expYear": expYear,
                "last4": last4,
                "bin": bin,
                "network": network,
                "fundingType": fundingType,
                "issuerCountry": issuerCountry,
            }
    
    expMonth: MetaOapg.properties.expMonth
    last4: MetaOapg.properties.last4
    expYear: MetaOapg.properties.expYear
    bin: MetaOapg.properties.bin
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> MetaOapg.properties.expMonth: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> MetaOapg.properties.expYear: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last4"]) -> MetaOapg.properties.last4: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bin"]) -> MetaOapg.properties.bin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fundingType"]) -> MetaOapg.properties.fundingType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["issuerCountry"]) -> MetaOapg.properties.issuerCountry: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["expMonth", "expYear", "last4", "bin", "network", "fundingType", "issuerCountry", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> MetaOapg.properties.expMonth: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> MetaOapg.properties.expYear: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last4"]) -> MetaOapg.properties.last4: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bin"]) -> MetaOapg.properties.bin: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> typing.Union[MetaOapg.properties.network, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fundingType"]) -> typing.Union[MetaOapg.properties.fundingType, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["issuerCountry"]) -> typing.Union[MetaOapg.properties.issuerCountry, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["expMonth", "expYear", "last4", "bin", "network", "fundingType", "issuerCountry", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expMonth: typing.Union[MetaOapg.properties.expMonth, decimal.Decimal, int, ],
        last4: typing.Union[MetaOapg.properties.last4, str, ],
        expYear: typing.Union[MetaOapg.properties.expYear, decimal.Decimal, int, ],
        bin: typing.Union[MetaOapg.properties.bin, str, ],
        network: typing.Union[MetaOapg.properties.network, str, schemas.Unset] = schemas.unset,
        fundingType: typing.Union[MetaOapg.properties.fundingType, str, schemas.Unset] = schemas.unset,
        issuerCountry: typing.Union[MetaOapg.properties.issuerCountry, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TokenizedCardDetails':
        return super().__new__(
            cls,
            *_args,
            expMonth=expMonth,
            last4=last4,
            expYear=expYear,
            bin=bin,
            network=network,
            fundingType=fundingType,
            issuerCountry=issuerCountry,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class VerificationErrorCode(
    schemas.EnumBase,
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Indicates the failure reason of the card verification. Only present on cards with failed verification. Possible values are [verification_failed, verification_fraud_detected, verification_denied, verification_not_supported_by_issuer, verification_stopped_by_issuer, card_failed, card_invalid, card_address_mismatch, card_zip_mismatch, card_cvv_invalid, card_expired, card_limit_violated, card_not_honored, card_cvv_required, credit_card_not_allowed, card_account_ineligible, card_network_unsupported]'
    """


    class MetaOapg:
        enum_value_to_name = {
            "verification_failed": "VERIFICATION_FAILED",
            "verification_fraud_detected": "VERIFICATION_FRAUD_DETECTED",
            "verification_denied": "VERIFICATION_DENIED",
            "verification_not_supported_by_issuer": "VERIFICATION_NOT_SUPPORTED_BY_ISSUER",
            "verification_stopped_by_issuer": "VERIFICATION_STOPPED_BY_ISSUER",
            "card_failed": "CARD_FAILED",
            "card_invalid": "CARD_INVALID",
            "card_address_mismatch": "CARD_ADDRESS_MISMATCH",
            "card_zip_mismatch": "CARD_ZIP_MISMATCH",
            "card_cvv_invalid": "CARD_CVV_INVALID",
            "card_expired": "CARD_EXPIRED",
            "card_limit_violated": "CARD_LIMIT_VIOLATED",
            "card_not_honored": "CARD_NOT_HONORED",
            "card_cvv_required": "CARD_CVV_REQUIRED",
            "credit_card_not_allowed": "CREDIT_CARD_NOT_ALLOWED",
            "card_account_ineligible": "CARD_ACCOUNT_INELIGIBLE",
            "card_network_unsupported": "CARD_NETWORK_UNSUPPORTED",
        }
    
    @schemas.classproperty
    def VERIFICATION_FAILED(cls):
        return cls("verification_failed")
    
    @schemas.classproperty
    def VERIFICATION_FRAUD_DETECTED(cls):
        return cls("verification_fraud_detected")
    
    @schemas.classproperty
    def VERIFICATION_DENIED(cls):
        return cls("verification_denied")
    
    @schemas.classproperty
    def VERIFICATION_NOT_SUPPORTED_BY_ISSUER(cls):
        return cls("verification_not_supported_by_issuer")
    
    @schemas.classproperty
    def VERIFICATION_STOPPED_BY_ISSUER(cls):
        return cls("verification_stopped_by_issuer")
    
    @schemas.classproperty
    def CARD_FAILED(cls):
        return cls("card_failed")
    
    @schemas.classproperty
    def CARD_INVALID(cls):
        return cls("card_invalid")
    
    @schemas.classproperty
    def CARD_ADDRESS_MISMATCH(cls):
        return cls("card_address_mismatch")
    
    @schemas.classproperty
    def CARD_ZIP_MISMATCH(cls):
        return cls("card_zip_mismatch")
    
    @schemas.classproperty
    def CARD_CVV_INVALID(cls):
        return cls("card_cvv_invalid")
    
    @schemas.classproperty
    def CARD_EXPIRED(cls):
        return cls("card_expired")
    
    @schemas.classproperty
    def CARD_LIMIT_VIOLATED(cls):
        return cls("card_limit_violated")
    
    @schemas.classproperty
    def CARD_NOT_HONORED(cls):
        return cls("card_not_honored")
    
    @schemas.classproperty
    def CARD_CVV_REQUIRED(cls):
        return cls("card_cvv_required")
    
    @schemas.classproperty
    def CREDIT_CARD_NOT_ALLOWED(cls):
        return cls("credit_card_not_allowed")
    
    @schemas.classproperty
    def CARD_ACCOUNT_INELIGIBLE(cls):
        return cls("card_account_ineligible")
    
    @schemas.classproperty
    def CARD_NETWORK_UNSUPPORTED(cls):
        return cls("card_network_unsupported")


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'VerificationErrorCode':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Card(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expMonth",
            "last4",
            "metadata",
            "updateDate",
            "billingDetails",
            "expYear",
            "fingerprint",
            "id",
            "verification",
            "createDate",
            "network",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def status() -> typing.Type['ExternalFiatAccountStatus']:
                return ExternalFiatAccountStatus
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
        
            @staticmethod
            def expMonth() -> typing.Type['CardExpMonth']:
                return CardExpMonth
        
            @staticmethod
            def expYear() -> typing.Type['CardExpYear']:
                return CardExpYear
            
            
            class network(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "VISA": "VISA",
                        "MASTERCARD": "MASTERCARD",
                        "AMEX": "AMEX",
                        "UNKNOWN": "UNKNOWN",
                    }
                
                @schemas.classproperty
                def VISA(cls):
                    return cls("VISA")
                
                @schemas.classproperty
                def MASTERCARD(cls):
                    return cls("MASTERCARD")
                
                @schemas.classproperty
                def AMEX(cls):
                    return cls("AMEX")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("UNKNOWN")
            last4 = schemas.StrSchema
            fingerprint = schemas.StrSchema
        
            @staticmethod
            def verification() -> typing.Type['CardVerificationResponse']:
                return CardVerificationResponse
        
            @staticmethod
            def metadata() -> typing.Type['MetadataPhoneEmail']:
                return MetadataPhoneEmail
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            bin = schemas.StrSchema
            issuerCountry = schemas.StrSchema
            
            
            class fundingType(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "credit": "CREDIT",
                        "debit": "DEBIT",
                        "prepaid": "PREPAID",
                        "unknown": "UNKNOWN",
                    }
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("credit")
                
                @schemas.classproperty
                def DEBIT(cls):
                    return cls("debit")
                
                @schemas.classproperty
                def PREPAID(cls):
                    return cls("prepaid")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("unknown")
        
            @staticmethod
            def errorCode() -> typing.Type['VerificationErrorCode']:
                return VerificationErrorCode
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            __annotations__ = {
                "id": id,
                "status": status,
                "billingDetails": billingDetails,
                "expMonth": expMonth,
                "expYear": expYear,
                "network": network,
                "last4": last4,
                "fingerprint": fingerprint,
                "verification": verification,
                "metadata": metadata,
                "createDate": createDate,
                "updateDate": updateDate,
                "bin": bin,
                "issuerCountry": issuerCountry,
                "fundingType": fundingType,
                "errorCode": errorCode,
                "riskEvaluation": riskEvaluation,
            }
    
    expMonth: 'CardExpMonth'
    last4: MetaOapg.properties.last4
    metadata: 'MetadataPhoneEmail'
    updateDate: MetaOapg.properties.updateDate
    billingDetails: 'BillingDetails'
    expYear: 'CardExpYear'
    fingerprint: MetaOapg.properties.fingerprint
    id: MetaOapg.properties.id
    verification: 'CardVerificationResponse'
    createDate: MetaOapg.properties.createDate
    network: MetaOapg.properties.network
    status: 'ExternalFiatAccountStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last4"]) -> MetaOapg.properties.last4: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verification"]) -> 'CardVerificationResponse': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataPhoneEmail': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bin"]) -> MetaOapg.properties.bin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["issuerCountry"]) -> MetaOapg.properties.issuerCountry: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fundingType"]) -> MetaOapg.properties.fundingType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorCode"]) -> 'VerificationErrorCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "status", "billingDetails", "expMonth", "expYear", "network", "last4", "fingerprint", "verification", "metadata", "createDate", "updateDate", "bin", "issuerCountry", "fundingType", "errorCode", "riskEvaluation", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last4"]) -> MetaOapg.properties.last4: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verification"]) -> 'CardVerificationResponse': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataPhoneEmail': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bin"]) -> typing.Union[MetaOapg.properties.bin, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["issuerCountry"]) -> typing.Union[MetaOapg.properties.issuerCountry, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fundingType"]) -> typing.Union[MetaOapg.properties.fundingType, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorCode"]) -> typing.Union['VerificationErrorCode', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "status", "billingDetails", "expMonth", "expYear", "network", "last4", "fingerprint", "verification", "metadata", "createDate", "updateDate", "bin", "issuerCountry", "fundingType", "errorCode", "riskEvaluation", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expMonth: 'CardExpMonth',
        last4: typing.Union[MetaOapg.properties.last4, str, ],
        metadata: 'MetadataPhoneEmail',
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, ],
        billingDetails: 'BillingDetails',
        expYear: 'CardExpYear',
        fingerprint: typing.Union[MetaOapg.properties.fingerprint, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        verification: 'CardVerificationResponse',
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        status: 'ExternalFiatAccountStatus',
        bin: typing.Union[MetaOapg.properties.bin, str, schemas.Unset] = schemas.unset,
        issuerCountry: typing.Union[MetaOapg.properties.issuerCountry, str, schemas.Unset] = schemas.unset,
        fundingType: typing.Union[MetaOapg.properties.fundingType, str, schemas.Unset] = schemas.unset,
        errorCode: typing.Union['VerificationErrorCode', schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Card':
        return super().__new__(
            cls,
            *_args,
            expMonth=expMonth,
            last4=last4,
            metadata=metadata,
            updateDate=updateDate,
            billingDetails=billingDetails,
            expYear=expYear,
            fingerprint=fingerprint,
            id=id,
            verification=verification,
            createDate=createDate,
            network=network,
            status=status,
            bin=bin,
            issuerCountry=issuerCountry,
            fundingType=fundingType,
            errorCode=errorCode,
            riskEvaluation=riskEvaluation,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.billing_details import BillingDetails
from circle.model.card_exp_month import CardExpMonth
from circle.model.card_exp_year import CardExpYear
from circle.model.card_verification_response import CardVerificationResponse
from circle.model.external_fiat_account_status import ExternalFiatAccountStatus
from circle.model.metadata_phone_email import MetadataPhoneEmail
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.verification_error_code import VerificationErrorCode



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class WireInstructionBeneficiaryBank(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            name = schemas.StrSchema
            swiftCode = schemas.StrSchema
            routingNumber = schemas.StrSchema
            accountNumber = schemas.StrSchema
            currency = schemas.StrSchema
            address = schemas.StrSchema
            city = schemas.StrSchema
            postalCode = schemas.StrSchema
            country = schemas.StrSchema
            __annotations__ = {
                "name": name,
                "swiftCode": swiftCode,
                "routingNumber": routingNumber,
                "accountNumber": accountNumber,
                "currency": currency,
                "address": address,
                "city": city,
                "postalCode": postalCode,
                "country": country,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["swiftCode"]) -> MetaOapg.properties.swiftCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["routingNumber"]) -> MetaOapg.properties.routingNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["accountNumber"]) -> MetaOapg.properties.accountNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["city"]) -> MetaOapg.properties.city: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["postalCode"]) -> MetaOapg.properties.postalCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["country"]) -> MetaOapg.properties.country: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "swiftCode", "routingNumber", "accountNumber", "currency", "address", "city", "postalCode", "country", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["swiftCode"]) -> typing.Union[MetaOapg.properties.swiftCode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["routingNumber"]) -> typing.Union[MetaOapg.properties.routingNumber, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["accountNumber"]) -> typing.Union[MetaOapg.properties.accountNumber, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["city"]) -> typing.Union[MetaOapg.properties.city, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["postalCode"]) -> typing.Union[MetaOapg.properties.postalCode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["country"]) -> typing.Union[MetaOapg.properties.country, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "swiftCode", "routingNumber", "accountNumber", "currency", "address", "city", "postalCode", "country", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        swiftCode: typing.Union[MetaOapg.properties.swiftCode, str, schemas.Unset] = schemas.unset,
        routingNumber: typing.Union[MetaOapg.properties.routingNumber, str, schemas.Unset] = schemas.unset,
        accountNumber: typing.Union[MetaOapg.properties.accountNumber, str, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
        city: typing.Union[MetaOapg.properties.city, str, schemas.Unset] = schemas.unset,
        postalCode: typing.Union[MetaOapg.properties.postalCode, str, schemas.Unset] = schemas.unset,
        country: typing.Union[MetaOapg.properties.country, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WireInstructionBeneficiaryBank':
        return super().__new__(
            cls,
            *_args,
            name=name,
            swiftCode=swiftCode,
            routingNumber=routingNumber,
            accountNumber=accountNumber,
            currency=currency,
            address=address,
            city=city,
            postalCode=postalCode,
            country=country,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Chain(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A blockchain that a given currency is available on.
    """


    class MetaOapg:
        enum_value_to_name = {
            "ALGO": "ALGO",
            "ARB": "ARB",
            "AVAX": "AVAX",
            "BASE": "BASE",
            "BTC": "BTC",
            "ETH": "ETH",
            "FLOW": "FLOW",
            "HBAR": "HBAR",
            "NEAR": "NEAR",
            "NOBLE": "NOBLE",
            "OP": "OP",
            "PAH": "PAH",
            "POLY": "POLY",
            "SOL": "SOL",
            "TRX": "TRX",
            "XLM": "XLM",
        }
    
    @schemas.classproperty
    def ALGO(cls):
        return cls("ALGO")
    
    @schemas.classproperty
    def ARB(cls):
        return cls("ARB")
    
    @schemas.classproperty
    def AVAX(cls):
        return cls("AVAX")
    
    @schemas.classproperty
    def BASE(cls):
        return cls("BASE")
    
    @schemas.classproperty
    def BTC(cls):
        return cls("BTC")
    
    @schemas.classproperty
    def ETH(cls):
        return cls("ETH")
    
    @schemas.classproperty
    def FLOW(cls):
        return cls("FLOW")
    
    @schemas.classproperty
    def HBAR(cls):
        return cls("HBAR")
    
    @schemas.classproperty
    def NEAR(cls):
        return cls("NEAR")
    
    @schemas.classproperty
    def NOBLE(cls):
        return cls("NOBLE")
    
    @schemas.classproperty
    def OP(cls):
        return cls("OP")
    
    @schemas.classproperty
    def PAH(cls):
        return cls("PAH")
    
    @schemas.classproperty
    def POLY(cls):
        return cls("POLY")
    
    @schemas.classproperty
    def SOL(cls):
        return cls("SOL")
    
    @schemas.classproperty
    def TRX(cls):
        return cls("TRX")
    
    @schemas.classproperty
    def XLM(cls):
        return cls("XLM")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentInfoPaymentAndRefund(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status information of the related payment. This property is only present on refund or cancel items.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.UUIDSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("payment")
                
                @schemas.classproperty
                def REFUND(cls):
                    return cls("refund")
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            
            
            class description(
                schemas.EnumBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "Payment": "PAYMENT",
                    }
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("Payment")
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'description':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def status() -> typing.Type['PaymentStatus']:
                return PaymentStatus
        
            @staticmethod
            def requiredAction() -> typing.Type['RequiredAction']:
                return RequiredAction
        
            @staticmethod
            def fees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            createDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "type": type,
                "amount": amount,
                "description": description,
                "status": status,
                "requiredAction": requiredAction,
                "fees": fees,
                "createDate": createDate,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'PaymentStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["requiredAction"]) -> 'RequiredAction': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "type", "amount", "description", "status", "requiredAction", "fees", "createDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['PaymentStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["requiredAction"]) -> typing.Union['RequiredAction', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "type", "amount", "description", "status", "requiredAction", "fees", "createDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
        amount: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, None, str, schemas.Unset] = schemas.unset,
        status: typing.Union['PaymentStatus', schemas.Unset] = schemas.unset,
        requiredAction: typing.Union['RequiredAction', schemas.Unset] = schemas.unset,
        fees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentInfoPaymentAndRefund':
        return super().__new__(
            cls,
            *_args,
            id=id,
            type=type,
            amount=amount,
            description=description,
            status=status,
            requiredAction=requiredAction,
            fees=fees,
            createDate=createDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.payment_status import PaymentStatus
from circle.model.required_action import RequiredAction



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class UnwithdrawalObject(
    schemas.DictBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneFrozenDictMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Return information if the payout is returned by bank. Only present if `errorCode` of payout is `transaction_returned`.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.UUIDSchema
            payoutId = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def fees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            reason = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "pending": "PENDING",
                        "complete": "COMPLETE",
                        "failed": "FAILED",
                    }
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("pending")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("complete")
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "payoutId": payoutId,
                "amount": amount,
                "fees": fees,
                "reason": reason,
                "status": status,
                "createDate": createDate,
                "updateDate": updateDate,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["payoutId"]) -> MetaOapg.properties.payoutId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "payoutId", "amount", "fees", "reason", "status", "createDate", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["payoutId"]) -> typing.Union[MetaOapg.properties.payoutId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> typing.Union[MetaOapg.properties.reason, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "payoutId", "amount", "fees", "reason", "status", "createDate", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, None, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        payoutId: typing.Union[MetaOapg.properties.payoutId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        amount: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        fees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        reason: typing.Union[MetaOapg.properties.reason, str, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'UnwithdrawalObject':
        return super().__new__(
            cls,
            *_args,
            id=id,
            payoutId=payoutId,
            amount=amount,
            fees=fees,
            reason=reason,
            status=status,
            createDate=createDate,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BasicChargeback(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "merchantId",
            "paymentId",
            "history",
            "id",
            "reasonCode",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
            paymentId = schemas.UUIDSchema
            merchantId = schemas.UUIDSchema
            reasonCode = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['ChargebackStatus']:
                return ChargebackStatus
            
            
            class history(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    min_items = 1
                    
                    @staticmethod
                    def items() -> typing.Type['BasicChargebackHistory']:
                        return BasicChargebackHistory
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['BasicChargebackHistory'], typing.List['BasicChargebackHistory']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'history':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'BasicChargebackHistory':
                    return super().__getitem__(i)
        
            @staticmethod
            def category() -> typing.Type['ChargebackCategories']:
                return ChargebackCategories
            __annotations__ = {
                "id": id,
                "paymentId": paymentId,
                "merchantId": merchantId,
                "reasonCode": reasonCode,
                "status": status,
                "history": history,
                "category": category,
            }
    
    merchantId: MetaOapg.properties.merchantId
    paymentId: MetaOapg.properties.paymentId
    history: MetaOapg.properties.history
    id: MetaOapg.properties.id
    reasonCode: MetaOapg.properties.reasonCode
    status: 'ChargebackStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentId"]) -> MetaOapg.properties.paymentId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reasonCode"]) -> MetaOapg.properties.reasonCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ChargebackStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["history"]) -> MetaOapg.properties.history: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["category"]) -> 'ChargebackCategories': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "paymentId", "merchantId", "reasonCode", "status", "history", "category", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentId"]) -> MetaOapg.properties.paymentId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reasonCode"]) -> MetaOapg.properties.reasonCode: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'ChargebackStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["history"]) -> MetaOapg.properties.history: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["category"]) -> typing.Union['ChargebackCategories', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "paymentId", "merchantId", "reasonCode", "status", "history", "category", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        merchantId: typing.Union[MetaOapg.properties.merchantId, str, uuid.UUID, ],
        paymentId: typing.Union[MetaOapg.properties.paymentId, str, uuid.UUID, ],
        history: typing.Union[MetaOapg.properties.history, list, tuple, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        reasonCode: typing.Union[MetaOapg.properties.reasonCode, str, ],
        status: 'ChargebackStatus',
        category: typing.Union['ChargebackCategories', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BasicChargeback':
        return super().__new__(
            cls,
            *_args,
            merchantId=merchantId,
            paymentId=paymentId,
            history=history,
            id=id,
            reasonCode=reasonCode,
            status=status,
            category=category,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.basic_chargeback_history import BasicChargebackHistory
from circle.model.chargeback_categories import ChargebackCategories
from circle.model.chargeback_status import ChargebackStatus



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Timeline(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "time",
            "status",
        }
        
        class properties:
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "created": "CREATED",
                        "pending": "PENDING",
                        "complete": "COMPLETE",
                        "expired": "EXPIRED",
                        "failed": "FAILED",
                        "refunded": "REFUNDED",
                    }
                
                @schemas.classproperty
                def CREATED(cls):
                    return cls("created")
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("pending")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("complete")
                
                @schemas.classproperty
                def EXPIRED(cls):
                    return cls("expired")
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
                
                @schemas.classproperty
                def REFUNDED(cls):
                    return cls("refunded")
            time = schemas.DateTimeSchema
            
            
            class context(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "underpaid": "UNDERPAID",
                        "paid": "PAID",
                        "overpaid": "OVERPAID",
                    }
                
                @schemas.classproperty
                def UNDERPAID(cls):
                    return cls("underpaid")
                
                @schemas.classproperty
                def PAID(cls):
                    return cls("paid")
                
                @schemas.classproperty
                def OVERPAID(cls):
                    return cls("overpaid")
            
            
            class reason(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "requested_by_merchant": "REQUESTED_BY_MERCHANT",
                        "fee_collection_failed": "FEE_COLLECTION_FAILED",
                    }
                
                @schemas.classproperty
                def REQUESTED_BY_MERCHANT(cls):
                    return cls("requested_by_merchant")
                
                @schemas.classproperty
                def FEE_COLLECTION_FAILED(cls):
                    return cls("fee_collection_failed")
            __annotations__ = {
                "status": status,
                "time": time,
                "context": context,
                "reason": reason,
            }
    
    time: MetaOapg.properties.time
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["time"]) -> MetaOapg.properties.time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["context"]) -> MetaOapg.properties.context: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["status", "time", "context", "reason", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["time"]) -> MetaOapg.properties.time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["context"]) -> typing.Union[MetaOapg.properties.context, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> typing.Union[MetaOapg.properties.reason, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["status", "time", "context", "reason", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        time: typing.Union[MetaOapg.properties.time, str, datetime, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        context: typing.Union[MetaOapg.properties.context, str, schemas.Unset] = schemas.unset,
        reason: typing.Union[MetaOapg.properties.reason, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Timeline':
        return super().__new__(
            cls,
            *_args,
            time=time,
            status=status,
            context=context,
            reason=reason,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class TransferErrorCode(
    schemas.EnumBase,
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Indicates the failure reason of a transfer. Only present for transfers in a `failed` state. Possible values are `insufficient_funds`, `blockchain_error` and `transfer_denied` and `transfer_failed`
    """


    class MetaOapg:
        enum_value_to_name = {
            "transfer_failed": "TRANSFER_FAILED",
            "transfer_denied": "TRANSFER_DENIED",
            "blockchain_error": "BLOCKCHAIN_ERROR",
            "insufficient_funds": "INSUFFICIENT_FUNDS",
        }
    
    @schemas.classproperty
    def TRANSFER_FAILED(cls):
        return cls("transfer_failed")
    
    @schemas.classproperty
    def TRANSFER_DENIED(cls):
        return cls("transfer_denied")
    
    @schemas.classproperty
    def BLOCKCHAIN_ERROR(cls):
        return cls("blockchain_error")
    
    @schemas.classproperty
    def INSUFFICIENT_FUNDS(cls):
        return cls("insufficient_funds")


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'TransferErrorCode':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.ping.get import Ping


class HealthApi(
    Ping,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class TransferDetailedTransfer(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A transfer of funds.
    """


    class MetaOapg:
        required = {
            "amount",
            "destination",
            "id",
            "source",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def source() -> typing.Type['TransferSourceLocation']:
                return TransferSourceLocation
        
            @staticmethod
            def destination() -> typing.Type['TransferDestinationLocation']:
                return TransferDestinationLocation
        
            @staticmethod
            def amount() -> typing.Type['Money']:
                return Money
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("pending")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("complete")
            
            
            class fees(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Fee']:
                        return Fee
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Fee'], typing.List['Fee']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fees':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Fee':
                    return super().__getitem__(i)
            transactionHash = schemas.StrSchema
        
            @staticmethod
            def errorCode() -> typing.Type['TransferErrorCode']:
                return TransferErrorCode
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            createDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "source": source,
                "destination": destination,
                "amount": amount,
                "status": status,
                "fees": fees,
                "transactionHash": transactionHash,
                "errorCode": errorCode,
                "riskEvaluation": riskEvaluation,
                "createDate": createDate,
            }
    
    amount: 'Money'
    destination: 'TransferDestinationLocation'
    id: MetaOapg.properties.id
    source: 'TransferSourceLocation'
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source"]) -> 'TransferSourceLocation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination"]) -> 'TransferDestinationLocation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'Money': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> MetaOapg.properties.fees: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorCode"]) -> 'TransferErrorCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "source", "destination", "amount", "status", "fees", "transactionHash", "errorCode", "riskEvaluation", "createDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> 'TransferSourceLocation': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination"]) -> 'TransferDestinationLocation': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'Money': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union[MetaOapg.properties.fees, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionHash"]) -> typing.Union[MetaOapg.properties.transactionHash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorCode"]) -> typing.Union['TransferErrorCode', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "source", "destination", "amount", "status", "fees", "transactionHash", "errorCode", "riskEvaluation", "createDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'Money',
        destination: 'TransferDestinationLocation',
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        source: 'TransferSourceLocation',
        status: typing.Union[MetaOapg.properties.status, str, ],
        fees: typing.Union[MetaOapg.properties.fees, list, tuple, schemas.Unset] = schemas.unset,
        transactionHash: typing.Union[MetaOapg.properties.transactionHash, str, schemas.Unset] = schemas.unset,
        errorCode: typing.Union['TransferErrorCode', schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TransferDetailedTransfer':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            destination=destination,
            id=id,
            source=source,
            status=status,
            fees=fees,
            transactionHash=transactionHash,
            errorCode=errorCode,
            riskEvaluation=riskEvaluation,
            createDate=createDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fee import Fee
from circle.model.money import Money
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.transfer_destination_location import TransferDestinationLocation
from circle.model.transfer_error_code import TransferErrorCode
from circle.model.transfer_source_location import TransferSourceLocation



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ContinuousPaymentIntent(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "settlementCurrency",
            "paymentMethods",
            "currency",
            "type",
        }
        
        class properties:
            
            
            class currency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class settlementCurrency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class paymentMethods(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentMethodBlockchain']:
                        return PaymentMethodBlockchain
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentMethodBlockchain'], typing.List['PaymentMethodBlockchain']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentMethods':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentMethodBlockchain':
                    return super().__getitem__(i)
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CONTINUOUS(cls):
                    return cls("continuous")
            id = schemas.UUIDSchema
        
            @staticmethod
            def amountPaid() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
        
            @staticmethod
            def amountRefunded() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
            
            
            class fees(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentIntentFees']:
                        return PaymentIntentFees
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentIntentFees'], typing.List['PaymentIntentFees']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fees':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentIntentFees':
                    return super().__getitem__(i)
            
            
            class timeline(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Timeline']:
                        return Timeline
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Timeline'], typing.List['Timeline']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'timeline':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Timeline':
                    return super().__getitem__(i)
            updateDate = schemas.StrSchema
            createDate = schemas.StrSchema
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            __annotations__ = {
                "currency": currency,
                "settlementCurrency": settlementCurrency,
                "paymentMethods": paymentMethods,
                "type": type,
                "id": id,
                "amountPaid": amountPaid,
                "amountRefunded": amountRefunded,
                "fees": fees,
                "timeline": timeline,
                "updateDate": updateDate,
                "createDate": createDate,
                "merchantWalletId": merchantWalletId,
            }
    
    settlementCurrency: MetaOapg.properties.settlementCurrency
    paymentMethods: MetaOapg.properties.paymentMethods
    currency: MetaOapg.properties.currency
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountPaid"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountRefunded"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> MetaOapg.properties.fees: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timeline"]) -> MetaOapg.properties.timeline: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["currency", "settlementCurrency", "paymentMethods", "type", "id", "amountPaid", "amountRefunded", "fees", "timeline", "updateDate", "createDate", "merchantWalletId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountPaid"]) -> typing.Union['CryptoPaymentsMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountRefunded"]) -> typing.Union['CryptoPaymentsMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union[MetaOapg.properties.fees, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timeline"]) -> typing.Union[MetaOapg.properties.timeline, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["currency", "settlementCurrency", "paymentMethods", "type", "id", "amountPaid", "amountRefunded", "fees", "timeline", "updateDate", "createDate", "merchantWalletId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        settlementCurrency: typing.Union[MetaOapg.properties.settlementCurrency, str, ],
        paymentMethods: typing.Union[MetaOapg.properties.paymentMethods, list, tuple, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        amountPaid: typing.Union['CryptoPaymentsMoney', schemas.Unset] = schemas.unset,
        amountRefunded: typing.Union['CryptoPaymentsMoney', schemas.Unset] = schemas.unset,
        fees: typing.Union[MetaOapg.properties.fees, list, tuple, schemas.Unset] = schemas.unset,
        timeline: typing.Union[MetaOapg.properties.timeline, list, tuple, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ContinuousPaymentIntent':
        return super().__new__(
            cls,
            *_args,
            settlementCurrency=settlementCurrency,
            paymentMethods=paymentMethods,
            currency=currency,
            type=type,
            id=id,
            amountPaid=amountPaid,
            amountRefunded=amountRefunded,
            fees=fees,
            timeline=timeline,
            updateDate=updateDate,
            createDate=createDate,
            merchantWalletId=merchantWalletId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payments_money import CryptoPaymentsMoney
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_intent_fees import PaymentIntentFees
from circle.model.payment_method_blockchain import PaymentMethodBlockchain
from circle.model.timeline import Timeline



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_transfers.post import CreateBusinessTransfer
from circle.paths.v1_transfers.post import CreateTransfer
from circle.paths.v1_business_account_transfers_id.get import GetBusinessTransfer
from circle.paths.v1_transfers_id.get import GetTransfer
from circle.paths.v1_business_account_transfers.get import ListBusinessTransfers
from circle.paths.v1_transfers.get import ListTransfers


class TransfersApi(
    CreateBusinessTransfer,
    CreateTransfer,
    GetBusinessTransfer,
    GetTransfer,
    ListBusinessTransfers,
    ListTransfers,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_mocks_cards_chargebacks.post import CreateMockChargeback
from circle.paths.v1_chargebacks_id.get import GetChargeback
from circle.paths.v1_chargebacks.get import ListChargebacks


class ChargebacksApi(
    CreateMockChargeback,
    GetChargeback,
    ListChargebacks,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_banks_cbit.post import CreateBusinessCbitAccount
from circle.paths.v1_business_account_banks_cbit_id.get import GetBusinessCbitAccount
from circle.paths.v1_business_account_banks_cbit_id_instructions.get import GetBusinessCbitAccountInstructions
from circle.paths.v1_business_account_banks_cbit.get import ListBusinessCbitAccounts


class CBITApi(
    CreateBusinessCbitAccount,
    GetBusinessCbitAccount,
    GetBusinessCbitAccountInstructions,
    ListBusinessCbitAccounts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentErrorCode(
    schemas.EnumBase,
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Indicates the failure reason of a payment. Only present for payments in failed state. Possible values are [`payment_failed`, `payment_fraud_detected`, `payment_denied`, `payment_not_supported_by_issuer`, `payment_not_funded`, `payment_unprocessable`, `payment_stopped_by_issuer`, `payment_canceled`, `payment_returned`, `payment_failed_balance_check`, `card_failed`, `card_invalid`, `card_address_mismatch`, `card_zip_mismatch`, `card_cvv_invalid`, `card_expired`, `card_limit_violated`, `card_not_honored`, `card_cvv_required`, `credit_card_not_allowed`, `card_account_ineligible`, `card_network_unsupported`, `channel_invalid`, `unauthorized_transaction`, `bank_account_ineligible`, `bank_transaction_error`, `invalid_account_number`, `invalid_wire_rtn`, `invalid_ach_rtn`, `vendor_inactive`]'
    """


    class MetaOapg:
        enum_value_to_name = {
            "payment_failed": "PAYMENT_FAILED",
            "payment_fraud_detected": "PAYMENT_FRAUD_DETECTED",
            "payment_denied": "PAYMENT_DENIED",
            "payment_not_supported_by_issuer": "PAYMENT_NOT_SUPPORTED_BY_ISSUER",
            "payment_not_funded": "PAYMENT_NOT_FUNDED",
            "payment_unprocessable": "PAYMENT_UNPROCESSABLE",
            "payment_stopped_by_issuer": "PAYMENT_STOPPED_BY_ISSUER",
            "payment_canceled": "PAYMENT_CANCELED",
            "payment_returned": "PAYMENT_RETURNED",
            "payment_failed_balance_check": "PAYMENT_FAILED_BALANCE_CHECK",
            "card_failed": "CARD_FAILED",
            "card_invalid": "CARD_INVALID",
            "card_address_mismatch": "CARD_ADDRESS_MISMATCH",
            "card_zip_mismatch": "CARD_ZIP_MISMATCH",
            "card_cvv_invalid": "CARD_CVV_INVALID",
            "card_expired": "CARD_EXPIRED",
            "card_limit_violated": "CARD_LIMIT_VIOLATED",
            "card_not_honored": "CARD_NOT_HONORED",
            "card_cvv_required": "CARD_CVV_REQUIRED",
            "card_restricted,": "CARD_RESTRICTED",
            "card_account_ineligible": "CARD_ACCOUNT_INELIGIBLE",
            "card_network_unsupported": "CARD_NETWORK_UNSUPPORTED",
            "channel_invalid": "CHANNEL_INVALID",
            "unauthorized_transaction": "UNAUTHORIZED_TRANSACTION",
            "bank_account_ineligible": "BANK_ACCOUNT_INELIGIBLE",
            "bank_transaction_error": "BANK_TRANSACTION_ERROR",
            "invalid_account_number": "INVALID_ACCOUNT_NUMBER",
            "invalid_wire_rtn": "INVALID_WIRE_RTN",
            "invalid_ach_rtn": "INVALID_ACH_RTN",
            "ref_id_invalid": "REF_ID_INVALID",
            "account_name_mismatch": "ACCOUNT_NAME_MISMATCH",
            "account_number_mismatch": "ACCOUNT_NUMBER_MISMATCH",
            "account_ineligible": "ACCOUNT_INELIGIBLE",
            "wallet_address_mismatch": "WALLET_ADDRESS_MISMATCH",
            "customer_name_mismatch": "CUSTOMER_NAME_MISMATCH",
            "institution_name_mismatch": "INSTITUTION_NAME_MISMATCH",
            "vendor_inactive": "VENDOR_INACTIVE",
        }
    
    @schemas.classproperty
    def PAYMENT_FAILED(cls):
        return cls("payment_failed")
    
    @schemas.classproperty
    def PAYMENT_FRAUD_DETECTED(cls):
        return cls("payment_fraud_detected")
    
    @schemas.classproperty
    def PAYMENT_DENIED(cls):
        return cls("payment_denied")
    
    @schemas.classproperty
    def PAYMENT_NOT_SUPPORTED_BY_ISSUER(cls):
        return cls("payment_not_supported_by_issuer")
    
    @schemas.classproperty
    def PAYMENT_NOT_FUNDED(cls):
        return cls("payment_not_funded")
    
    @schemas.classproperty
    def PAYMENT_UNPROCESSABLE(cls):
        return cls("payment_unprocessable")
    
    @schemas.classproperty
    def PAYMENT_STOPPED_BY_ISSUER(cls):
        return cls("payment_stopped_by_issuer")
    
    @schemas.classproperty
    def PAYMENT_CANCELED(cls):
        return cls("payment_canceled")
    
    @schemas.classproperty
    def PAYMENT_RETURNED(cls):
        return cls("payment_returned")
    
    @schemas.classproperty
    def PAYMENT_FAILED_BALANCE_CHECK(cls):
        return cls("payment_failed_balance_check")
    
    @schemas.classproperty
    def CARD_FAILED(cls):
        return cls("card_failed")
    
    @schemas.classproperty
    def CARD_INVALID(cls):
        return cls("card_invalid")
    
    @schemas.classproperty
    def CARD_ADDRESS_MISMATCH(cls):
        return cls("card_address_mismatch")
    
    @schemas.classproperty
    def CARD_ZIP_MISMATCH(cls):
        return cls("card_zip_mismatch")
    
    @schemas.classproperty
    def CARD_CVV_INVALID(cls):
        return cls("card_cvv_invalid")
    
    @schemas.classproperty
    def CARD_EXPIRED(cls):
        return cls("card_expired")
    
    @schemas.classproperty
    def CARD_LIMIT_VIOLATED(cls):
        return cls("card_limit_violated")
    
    @schemas.classproperty
    def CARD_NOT_HONORED(cls):
        return cls("card_not_honored")
    
    @schemas.classproperty
    def CARD_CVV_REQUIRED(cls):
        return cls("card_cvv_required")
    
    @schemas.classproperty
    def CARD_RESTRICTED(cls):
        return cls("card_restricted,")
    
    @schemas.classproperty
    def CARD_ACCOUNT_INELIGIBLE(cls):
        return cls("card_account_ineligible")
    
    @schemas.classproperty
    def CARD_NETWORK_UNSUPPORTED(cls):
        return cls("card_network_unsupported")
    
    @schemas.classproperty
    def CHANNEL_INVALID(cls):
        return cls("channel_invalid")
    
    @schemas.classproperty
    def UNAUTHORIZED_TRANSACTION(cls):
        return cls("unauthorized_transaction")
    
    @schemas.classproperty
    def BANK_ACCOUNT_INELIGIBLE(cls):
        return cls("bank_account_ineligible")
    
    @schemas.classproperty
    def BANK_TRANSACTION_ERROR(cls):
        return cls("bank_transaction_error")
    
    @schemas.classproperty
    def INVALID_ACCOUNT_NUMBER(cls):
        return cls("invalid_account_number")
    
    @schemas.classproperty
    def INVALID_WIRE_RTN(cls):
        return cls("invalid_wire_rtn")
    
    @schemas.classproperty
    def INVALID_ACH_RTN(cls):
        return cls("invalid_ach_rtn")
    
    @schemas.classproperty
    def REF_ID_INVALID(cls):
        return cls("ref_id_invalid")
    
    @schemas.classproperty
    def ACCOUNT_NAME_MISMATCH(cls):
        return cls("account_name_mismatch")
    
    @schemas.classproperty
    def ACCOUNT_NUMBER_MISMATCH(cls):
        return cls("account_number_mismatch")
    
    @schemas.classproperty
    def ACCOUNT_INELIGIBLE(cls):
        return cls("account_ineligible")
    
    @schemas.classproperty
    def WALLET_ADDRESS_MISMATCH(cls):
        return cls("wallet_address_mismatch")
    
    @schemas.classproperty
    def CUSTOMER_NAME_MISMATCH(cls):
        return cls("customer_name_mismatch")
    
    @schemas.classproperty
    def INSTITUTION_NAME_MISMATCH(cls):
        return cls("institution_name_mismatch")
    
    @schemas.classproperty
    def VENDOR_INACTIVE(cls):
        return cls("vendor_inactive")


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'PaymentErrorCode':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



import typing_extensions

from circle.apis.tags import TagValues
from circle.apis.tags.addresses_api import AddressesApi
from circle.apis.tags.crypto_address_book_api import CryptoAddressBookApi
from circle.apis.tags.balances_api import BalancesApi
from circle.apis.tags.cards_api import CardsApi
from circle.apis.tags.payment_tokens_api import PaymentTokensApi
from circle.apis.tags.channels_api import ChannelsApi
from circle.apis.tags.chargebacks_api import ChargebacksApi
from circle.apis.tags.crypto_payment_intents_api import CryptoPaymentIntentsApi
from circle.apis.tags.deposits_api import DepositsApi
from circle.apis.tags.encryption_api import EncryptionApi
from circle.apis.tags.crypto_exchange_rates_api import CryptoExchangeRatesApi
from circle.apis.tags.health_api import HealthApi
from circle.apis.tags.management_api import ManagementApi
from circle.apis.tags.payments_api import PaymentsApi
from circle.apis.tags.pull_crypto_payments_api import PullCryptoPaymentsApi
from circle.apis.tags.payouts_api import PayoutsApi
from circle.apis.tags.settlements_api import SettlementsApi
from circle.apis.tags.cbit_api import CBITApi
from circle.apis.tags.stablecoins_api import StablecoinsApi
from circle.apis.tags.subscriptions_api import SubscriptionsApi
from circle.apis.tags.transfers_api import TransfersApi
from circle.apis.tags.wallets_api import WalletsApi
from circle.apis.tags.wires_api import WiresApi
from circle.apis.tags.checkout_sessions_api import CheckoutSessionsApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ADDRESSES: AddressesApi,
        TagValues.CRYPTO_ADDRESS_BOOK: CryptoAddressBookApi,
        TagValues.BALANCES: BalancesApi,
        TagValues.CARDS: CardsApi,
        TagValues.PAYMENT_TOKENS: PaymentTokensApi,
        TagValues.CHANNELS: ChannelsApi,
        TagValues.CHARGEBACKS: ChargebacksApi,
        TagValues.CRYPTO_PAYMENT_INTENTS: CryptoPaymentIntentsApi,
        TagValues.DEPOSITS: DepositsApi,
        TagValues.ENCRYPTION: EncryptionApi,
        TagValues.CRYPTO_EXCHANGE_RATES: CryptoExchangeRatesApi,
        TagValues.HEALTH: HealthApi,
        TagValues.MANAGEMENT: ManagementApi,
        TagValues.PAYMENTS: PaymentsApi,
        TagValues.PULL_CRYPTO_PAYMENTS: PullCryptoPaymentsApi,
        TagValues.PAYOUTS: PayoutsApi,
        TagValues.SETTLEMENTS: SettlementsApi,
        TagValues.CBIT: CBITApi,
        TagValues.STABLECOINS: StablecoinsApi,
        TagValues.SUBSCRIPTIONS: SubscriptionsApi,
        TagValues.TRANSFERS: TransfersApi,
        TagValues.WALLETS: WalletsApi,
        TagValues.WIRES: WiresApi,
        TagValues.CHECKOUT_SESSIONS: CheckoutSessionsApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ADDRESSES: AddressesApi,
        TagValues.CRYPTO_ADDRESS_BOOK: CryptoAddressBookApi,
        TagValues.BALANCES: BalancesApi,
        TagValues.CARDS: CardsApi,
        TagValues.PAYMENT_TOKENS: PaymentTokensApi,
        TagValues.CHANNELS: ChannelsApi,
        TagValues.CHARGEBACKS: ChargebacksApi,
        TagValues.CRYPTO_PAYMENT_INTENTS: CryptoPaymentIntentsApi,
        TagValues.DEPOSITS: DepositsApi,
        TagValues.ENCRYPTION: EncryptionApi,
        TagValues.CRYPTO_EXCHANGE_RATES: CryptoExchangeRatesApi,
        TagValues.HEALTH: HealthApi,
        TagValues.MANAGEMENT: ManagementApi,
        TagValues.PAYMENTS: PaymentsApi,
        TagValues.PULL_CRYPTO_PAYMENTS: PullCryptoPaymentsApi,
        TagValues.PAYOUTS: PayoutsApi,
        TagValues.SETTLEMENTS: SettlementsApi,
        TagValues.CBIT: CBITApi,
        TagValues.STABLECOINS: StablecoinsApi,
        TagValues.SUBSCRIPTIONS: SubscriptionsApi,
        TagValues.TRANSFERS: TransfersApi,
        TagValues.WALLETS: WalletsApi,
        TagValues.WIRES: WiresApi,
        TagValues.CHECKOUT_SESSIONS: CheckoutSessionsApi,
    }
)



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_address_book_recipients.post import CreateAddressBookRecipient
from circle.paths.v1_address_book_recipients_id.delete import DeleteAddressBookRecipient
from circle.paths.v1_address_book_recipients_id.get import GetAddressBookRecipient
from circle.paths.v1_address_book_recipients.get import ListAddressBookRecipients
from circle.paths.v1_address_book_recipients_id.patch import ModifyAddressBookRecipient


class CryptoAddressBookApi(
    CreateAddressBookRecipient,
    DeleteAddressBookRecipient,
    GetAddressBookRecipient,
    ListAddressBookRecipients,
    ModifyAddressBookRecipient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class AddressTag(
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The secondary identifier for a blockchain address. An example of this is the memo field on the Stellar network, which can be text, id, or hash format.
    """


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AddressTag':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



from circle.paths.v1_business_account_wallets_addresses_recipient.get import ApiForget
from circle.paths.v1_business_account_wallets_addresses_recipient.post import ApiForpost


class V1BusinessAccountWalletsAddressesRecipient(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Currency(
    schemas.EnumBase,
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A currency associated with a balance or address.
    """


    class MetaOapg:
        enum_value_to_name = {
            "USD": "USD",
            "EUR": "EUR",
            "BTC": "BTC",
            "ETH": "ETH",
        }
    
    @schemas.classproperty
    def USD(cls):
        return cls("USD")
    
    @schemas.classproperty
    def EUR(cls):
        return cls("EUR")
    
    @schemas.classproperty
    def BTC(cls):
        return cls("BTC")
    
    @schemas.classproperty
    def ETH(cls):
        return cls("ETH")


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Currency':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payments_id_cancel.post import CancelPayment
from circle.paths.v1_payments_id_capture.post import CapturePayment
from circle.paths.v1_mocks_payments_wire.post import CreateMockWirePayment
from circle.paths.v1_payments.post import CreatePayment
from circle.paths.v1_payments_id.get import GetPayment
from circle.paths.v1_payments.get import ListPayments
from circle.paths.v1_payments_id_refund.post import RefundPayment


class PaymentsApi(
    CancelPayment,
    CapturePayment,
    CreateMockWirePayment,
    CreatePayment,
    GetPayment,
    ListPayments,
    RefundPayment,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class DetailedCancel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "merchantId",
            "id",
            "source",
            "type",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CANCEL(cls):
                    return cls("cancel")
            merchantId = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def source() -> typing.Type['SourceResponse']:
                return SourceResponse
        
            @staticmethod
            def status() -> typing.Type['CancelRefundReversalStatus']:
                return CancelRefundReversalStatus
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            
            
            class description(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("Payment")
        
            @staticmethod
            def originalPayment() -> typing.Type['FiatPayment']:
                return FiatPayment
        
            @staticmethod
            def fees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            
            
            class trackingRef(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'trackingRef':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def errorCode() -> typing.Type['PaymentErrorCode']:
                return PaymentErrorCode
        
            @staticmethod
            def metadata() -> typing.Type['MetadataPhoneEmail']:
                return MetadataPhoneEmail
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            refund = schemas.BoolSchema
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "type": type,
                "merchantId": merchantId,
                "amount": amount,
                "source": source,
                "status": status,
                "merchantWalletId": merchantWalletId,
                "description": description,
                "originalPayment": originalPayment,
                "fees": fees,
                "trackingRef": trackingRef,
                "errorCode": errorCode,
                "metadata": metadata,
                "riskEvaluation": riskEvaluation,
                "refund": refund,
                "createDate": createDate,
                "updateDate": updateDate,
            }
    
    amount: 'FiatMoneyUsd'
    merchantId: MetaOapg.properties.merchantId
    id: MetaOapg.properties.id
    source: 'SourceResponse'
    type: MetaOapg.properties.type
    status: 'CancelRefundReversalStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source"]) -> 'SourceResponse': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'CancelRefundReversalStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["originalPayment"]) -> 'FiatPayment': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trackingRef"]) -> MetaOapg.properties.trackingRef: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorCode"]) -> 'PaymentErrorCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataPhoneEmail': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refund"]) -> MetaOapg.properties.refund: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "source", "status", "merchantWalletId", "description", "originalPayment", "fees", "trackingRef", "errorCode", "metadata", "riskEvaluation", "refund", "createDate", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> 'SourceResponse': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'CancelRefundReversalStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["originalPayment"]) -> typing.Union['FiatPayment', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trackingRef"]) -> typing.Union[MetaOapg.properties.trackingRef, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorCode"]) -> typing.Union['PaymentErrorCode', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union['MetadataPhoneEmail', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refund"]) -> typing.Union[MetaOapg.properties.refund, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "source", "status", "merchantWalletId", "description", "originalPayment", "fees", "trackingRef", "errorCode", "metadata", "riskEvaluation", "refund", "createDate", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'FiatMoneyUsd',
        merchantId: typing.Union[MetaOapg.properties.merchantId, str, uuid.UUID, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        source: 'SourceResponse',
        type: typing.Union[MetaOapg.properties.type, str, ],
        status: 'CancelRefundReversalStatus',
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        originalPayment: typing.Union['FiatPayment', schemas.Unset] = schemas.unset,
        fees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        trackingRef: typing.Union[MetaOapg.properties.trackingRef, None, str, schemas.Unset] = schemas.unset,
        errorCode: typing.Union['PaymentErrorCode', schemas.Unset] = schemas.unset,
        metadata: typing.Union['MetadataPhoneEmail', schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        refund: typing.Union[MetaOapg.properties.refund, bool, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DetailedCancel':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            merchantId=merchantId,
            id=id,
            source=source,
            type=type,
            status=status,
            merchantWalletId=merchantWalletId,
            description=description,
            originalPayment=originalPayment,
            fees=fees,
            trackingRef=trackingRef,
            errorCode=errorCode,
            metadata=metadata,
            riskEvaluation=riskEvaluation,
            refund=refund,
            createDate=createDate,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.cancel_refund_reversal_status import CancelRefundReversalStatus
from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.fiat_payment import FiatPayment
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.metadata_phone_email import MetadataPhoneEmail
from circle.model.payment_error_code import PaymentErrorCode
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.source_response import SourceResponse



from circle.paths.v1_wallets_wallet_id_addresses.get import ApiForget
from circle.paths.v1_wallets_wallet_id_addresses.post import ApiForpost


class V1WalletsWalletIdAddresses(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

# flake8: noqa

"""
    Generated by: https://openapi-generator.tech
"""

__version__ = "0.1.0-beta.12"

# import ApiClient
from circle.api_client import ApiClient

# import Configuration
from circle.configuration import Configuration

# import exceptions
from circle.exceptions import OpenApiException
from circle.exceptions import ApiAttributeError
from circle.exceptions import ApiTypeError
from circle.exceptions import ApiValueError
from circle.exceptions import ApiKeyError
from circle.exceptions import ApiException

from enum import Enum

# Global config variables and constants
class Environment(Enum):
    SANDBOX_BASE_URL = "https://api-sandbox.circle.com"
    PRODUCTION_BASE_URL = "https://api.circle.com"

api_key = "<replace-me-with-your-api-key>"
base_url = Environment.SANDBOX_BASE_URL



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_notifications_subscriptions.post import CreateSubscription
from circle.paths.v1_notifications_subscriptions_id.delete import DeleteSubscription
from circle.paths.v1_notifications_subscriptions.get import ListSubscriptions


class SubscriptionsApi(
    CreateSubscription,
    DeleteSubscription,
    ListSubscriptions,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class RiskEvaluation(
    schemas.DictBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneFrozenDictMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Results of risk evaluation. Only present if the payment is denied by Circle's risk service.
    """


    class MetaOapg:
        
        class properties:
            
            
            class decision(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def APPROVED(cls):
                    return cls("approved")
                
                @schemas.classproperty
                def DENIED(cls):
                    return cls("denied")
                
                @schemas.classproperty
                def REVIEW(cls):
                    return cls("review")
            
            
            class reason(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'reason':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "decision": decision,
                "reason": reason,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decision"]) -> MetaOapg.properties.decision: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["decision", "reason", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decision"]) -> typing.Union[MetaOapg.properties.decision, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> typing.Union[MetaOapg.properties.reason, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["decision", "reason", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, None, ],
        decision: typing.Union[MetaOapg.properties.decision, str, schemas.Unset] = schemas.unset,
        reason: typing.Union[MetaOapg.properties.reason, None, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'RiskEvaluation':
        return super().__new__(
            cls,
            *_args,
            decision=decision,
            reason=reason,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from circle.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ADDRESSES = "Addresses"
    CRYPTO_ADDRESS_BOOK = "Crypto Address Book"
    BALANCES = "Balances"
    CARDS = "Cards"
    PAYMENT_TOKENS = "Payment Tokens"
    CHANNELS = "Channels"
    CHARGEBACKS = "Chargebacks"
    CRYPTO_PAYMENT_INTENTS = "Crypto Payment Intents"
    DEPOSITS = "Deposits"
    ENCRYPTION = "Encryption"
    CRYPTO_EXCHANGE_RATES = "Crypto Exchange Rates"
    HEALTH = "Health"
    MANAGEMENT = "Management"
    PAYMENTS = "Payments"
    PULL_CRYPTO_PAYMENTS = "Pull Crypto Payments"
    PAYOUTS = "Payouts"
    SETTLEMENTS = "Settlements"
    CBIT = "CBIT"
    STABLECOINS = "Stablecoins"
    SUBSCRIPTIONS = "Subscriptions"
    TRANSFERS = "Transfers"
    WALLETS = "Wallets"
    WIRES = "Wires"
    CHECKOUT_SESSIONS = "Checkout Sessions"
